@@ -1,43 +1,43 @@
 package Switch::Plain;
 
 use v5.14.0;
+use strict;
 use warnings;
 
 use Carp qw(croak);
 
 use XSLoader;
 BEGIN {
-    our $VERSION = '0.03_01';
-    our $XS_VERSION = $VERSION;
-    $VERSION =~ tr/_//d;
-    XSLoader::load;
+	our $VERSION = '0.01';
+	XSLoader::load;
 }
 
 my %export = (
-    sswitch => FLAG_SSWITCH,
-    nswitch => FLAG_NSWITCH,
+	sswitch => FLAG_SSWITCH,
+	nswitch => FLAG_NSWITCH,
 );
 
-sub _port {
-    my $op = shift;
-
-    my $class = shift;
-
-    my @todo;
-    for my $item (@_) {
-        push @todo, $export{$item} || croak qq{"$item" is not exported by the $class module};
-    }
-    for my $item (@todo ? @todo : values %export) {
-        $op->(\$^H{+HINTK_FLAGS}, $item);
-    }
-}
-
 sub import {
-    _port sub { ${$_[0]} |= $_[1]; }, @_;
+	my $class = shift;
+
+	my @todo;
+	for my $item (@_) {
+		push @todo, $export{$item} || croak qq{"$item" is not exported by the $class module};
+	}
+	for my $item (@todo ? @todo : values %export) {
+		$^H{+HINTK_FLAGS} |= $item;
+	}
 }
 
 sub unimport {
-    _port sub { ${$_[0]} &= ~$_[1]; }, @_;
+	my $class = shift;
+	my @todo;
+	for my $item (@_) {
+		push @todo, $export{$item} || croak qq{"$item" is not exported by the $class module};
+	}
+	for my $item (@todo ? @todo : values %export) {
+		$^H{+HINTK_FLAGS} &= ~$item;
+	}
 }
 
 'ok'
@@ -133,12 +133,10 @@ L<smartmatch operator C<~~>|perlop/Smartmatch-Operator>.
 
 This module understands the following grammar:
 
-  switch_statement := switch_keyword switch_scrutinee switch_body
+  switch_statement := switch_keyword switch_body
 
   switch_keyword := 'sswitch' | 'nswitch'
 
-  switch_scrutinee := '(' EXPR ')'
-
   switch_body := '{' case_clause* '}'
 
   case_clause := case_pattern+ BLOCK
@@ -162,10 +160,10 @@ The meaning of a switch statement is given by the following translation rules:
 
 C<sswitch (FOO) { ... }> and C<nswitch (FOO) { ... }> turn into
 
-  do {
+  {
     local *_ = \FOO;
     ...
-  };
+  }
 
 That is, they alias L<C<$_>|perlvar/"$ARG"> to C<FOO> within the body of the switch statement.
 
@@ -216,7 +214,7 @@ Here's an example demonstrating all combinations:
 
 This is equivalent to:
 
-  do {
+  {
     # temporarily alias $_ to SCRUTINEE within this block:
     local *_ = \SCRUTINEE;
 
@@ -235,7 +233,7 @@ This is equivalent to:
     elsif (1) {
       BODY2
     }
-  };
+  }
 
 =head2 Differences between C<Switch::Plain> and C's C<switch>
 
@@ -319,7 +317,7 @@ Lukas Mai, C<< <l.mai at web.de> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012-2013 Lukas Mai.
+Copyright 2012 Lukas Mai.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
